@@ -26,4 +26,10 @@ eos.transaction({
       data: data_values
     }
   ]
-})
\ No newline at end of file
+}).then(function (value){
+        console.log(value);
+        return value;
+      }).catch(function (e) {
+      console.error(e);
+      process.exit(1);
+      })
\ No newline at end of file
